@@ -28,7 +28,6 @@
 #include <kxmlrpcclient/client.h>
 
 #include "kblog_debug.h"
-#include <KDateTime>
 #include <KLocalizedString>
 
 #include <QList>
@@ -58,7 +57,7 @@ Blogger1::~Blogger1()
 
 QString Blogger1::interfaceName() const
 {
-    return QLatin1String("Blogger 1.0");
+    return QStringLiteral("Blogger 1.0");
 }
 
 void Blogger1::setUrl(const QUrl &server)
@@ -383,7 +382,7 @@ void Blogger1Private::slotCreatePost(const QList<QVariant> &result, const QVaria
     if (result[0].type() == QVariant::String) {
         serverID = result[0].toString();
     } else if (result[0].type() == QVariant::Int) {
-        serverID = QString::fromLatin1("%1").arg(result[0].toInt());
+        serverID = QStringLiteral("%1").arg(result[0].toInt());
     }
     post->setPostId(serverID);
     post->setStatus(KBlog::BlogPost::Created);
@@ -465,17 +464,17 @@ bool Blogger1Private::readPostFromMap(
     if (!post) {
         return false;
     }
-    QStringList mapkeys = postInfo.keys();
-    qCDebug(KBLOG_LOG) << endl << "Keys:" << mapkeys.join(QStringLiteral(", "));
+
+    qCDebug(KBLOG_LOG) << endl << "Keys:" << QStringList(postInfo.keys()).join(QStringLiteral(", "));
     qCDebug(KBLOG_LOG) << endl;
 
-    KDateTime dt(postInfo[QStringLiteral("dateCreated")].toDateTime(), KDateTime::UTC);
+    QDateTime dt = postInfo[QStringLiteral("dateCreated")].toDateTime();
     if (dt.isValid() && !dt.isNull()) {
-        post->setCreationDateTime(dt.toLocalZone());
+        post->setCreationDateTime(dt.toLocalTime());
     }
-    dt = KDateTime(postInfo[QStringLiteral("lastModified")].toDateTime(), KDateTime::UTC);
+    dt = postInfo[QStringLiteral("lastModified")].toDateTime();
     if (dt.isValid() && !dt.isNull()) {
-        post->setModificationDateTime(dt.toLocalZone());
+        post->setModificationDateTime(dt.toLocalTime());
     }
     post->setPostId(postInfo[QStringLiteral("postid")].toString().isEmpty() ? postInfo[QStringLiteral("postId")].toString() :
                     postInfo[QStringLiteral("postid")].toString());
